import React, { useEffect, useState } from 'react'
import Taro, { useShareAppMessage, useRouter } from "@tarojs/taro";
import { useSelector, } from 'react-redux'
import { View, Input, Text, Image, Picker, Button } from '@tarojs/components'
import { AtModal, AtModalHeader, AtModalContent, AtModalAction } from "taro-ui"
import Loading from '@/compents/Loading'
import Layout from '../../layout/index'
import Tab from '../../compents/tab/index'
import Container from '../../compents/container/index'
import './index.scss'
import request from '../../util/request';

// Page({
//     data: {
//         text: 'init data',
//         array: [{ msg: '1' }, { msg: '2' }]
//     }
// })

const Index = () => {
    const router = useRouter()
    const { houseId } = router.params
    const [personNum, setPersonNum] = useState()
    const [startTime, setStartTime] = useState('')
    const [endTime, setEndTime] = useState('')
    // const [data,setData] = useState({})
    const [shareObj, setShareObj] = useState()
    const [showShareModal, setShowShareModal] = useState(false)

    useEffect(() => {
        request({ url: "/taHouseSetting/last", params: { houseId } }).then((res) => {
            if (res.data.data) {
                setPersonNum(res.data.data.personNum)
                setStartTime(res.data.data.startDate)
                setEndTime(res.data.data.endDate)
            }
        })
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [])

    const [showShareLoading, setShowShareLoading] = useState(false)
    
    const onTimeChange = (e) => {
        setStartTime(e.detail.value)
    }

    const handleShareReady = () => {

        const data = {
            houseId,
            personNum,
            startDate: startTime,
            endDate: endTime
        }
        
        setShowShareLoading(true)

        return request({ url: '/taHouseSetting', method: 'post', data }).then(res => {
            const { data } = res.data
            if (res.data.data) {
                console.log(data.taHouseOrder.orderId)
                const { orderId } = data.taHouseOrder
                return request({ url: `/taHouse/${houseId}/share` }).then(res => {

                    const share = {
                        title: '分享到微信',
                        imageUrl: (res.data.data || {}).image,
                        path: `/pages/index/index?houseId=${houseId}&personNum=${personNum}&startTime=${startTime}&endTime=${endTime}&orderId=${orderId}`
                    }

                    setShareObj(share)
                    setShowShareLoading(false)
                    setShowShareModal(true)
                })
            } else {
                setShowShareLoading(false)
                Taro.showModal({
                    title: '输入信息有误',
                    content: '请重新输入',
                    showCancel: false,
                    success: function (res) {
                        if (res.confirm) {
                            console.log('用户点击确定')
                        } else if (res.cancel) {
                            console.log('用户点击取消')
                        }
                    }
                })
            }

        })

    }

    useShareAppMessage(() => {
        return shareObj
    })

    return <View className='share'>
        <Layout>
            <View className='inputstyle-view'>
                <Text className='title'>入住人数</Text>
                <Container className='inputstyle-view-card ' style={{ borderRadius: '20rpx', padding: '0 40rpx' }} >
                    <Input type='number' value={personNum} onInput={(e) => setPersonNum(e.detail.value)} placeholderClass='placeholderinput' className='input' type='text' placeholder='' />
                </Container>
            </View>
            <View className='inputstyle-view'>
                <Text className='title'>入住日期</Text>
                <Container className='inputstyle-view-card ' style={{ borderRadius: '20rpx', padding: '0 40rpx' }} >

                    <Picker mode='date' onChange={onTimeChange}>
                        <View className='input' style={{ height: '44rpx', lineHeight: '44rpx', fontsize: '28rpx' }}>
                            {startTime}
                        </View>
                    </Picker>
                    {/* <Input placeholderClass='placeholderinput' className='input' type='text' placeholder='' /> */}
                </Container>
            </View>

            <View className='inputstyle-view'>
                <Text className='title'>离店日期</Text>
                <Container className='inputstyle-view-card ' style={{ borderRadius: '20rpx', padding: '0 40rpx' }} >
                    <Picker mode='date' onChange={(e) => { setEndTime(e.detail.value) }}>
                        <View className='input' style={{ height: '44rpx', lineHeight: '44rpx', fontsize: '28rpx' }}>
                            {endTime}
                        </View>
                    </Picker>
                </Container>
            </View>
        </Layout>
        <Tab className='addhousetab' color='#ffffff' pageState='3' onClick={handleShareReady} value={['分享到微信']} ></Tab>
        <AtModal isOpened={showShareLoading} closeOnClickOverlay={false}>
            <AtModalContent>
                <View style={{textAlign: 'center'}}>
                    <Loading size='48px' />
                </View>
                <View style={{marginTop: '2em', textAlign: 'center'}}>正在生成分享内容, 请稍候...</View>
            </AtModalContent>
        </AtModal>
        <AtModal isOpened={showShareModal}>
            <AtModalHeader>分享到微信</AtModalHeader>
            <AtModalAction>
                <Button open-type='share' onClick={() => setShowShareModal(false)}>去分享</Button>
            </AtModalAction>
        </AtModal>
    </View>
}

export default Index